paper-focusable

The "paper-focused" item allows you to handle focusing on items.
Focusable Item - active
This paragraph shows a style with the "paper-focusable[active]" selector. It functions much like using the "pressed" attribute.
Focusable Item - pressed
This paragraph shows a style with the "paper-focusable[pressed]" selector. It functions much like usin the "active" attribute.
Focusable Item - focused
This paragraph shows a style with the "paper-focusable[focused]" selector. This will be active on items that are focused but not active or pressed.
Focusable Item - disabled
This paragraph shows a style with the "disabled" attribute. The "paper-focusable" item with a "disabled" attribute cannot be selected, and will prevent mouse actions.
Focusable Item - toggle
This paragraph shows a style with the "isToggle" attribute. The "paper-focusable" item with an "isToggle" toggles the active state on each tap.